@@ -11,6 +11,7 @@ from thirdweb.core.classes.registry import ContractRegistry
 from thirdweb.types.contract import ContractType
 from thirdweb.types.sdk import SDKOptions
 from thirdweb.types.settings.metadata import (
+    EditionDropContractMetadata,
     NFTDropContractMetadata,
     EditionContractMetadata,
     MarketplaceContractMetadata,
@@ -70,6 +71,13 @@ class ContractDeployer(ProviderHandler):
 
         return self._deploy_contract(ContractType.NFT_DROP, metadata.to_json())
 
+    def deploy_edition_drop(self, metadata: EditionDropContractMetadata) -> str:
+        """
+        Deploy an Edition Drop contract
+        """
+
+        return self._deploy_contract(ContractType.EDITION_DROP, metadata.to_json())
+
     def _deploy_contract(
         self, contract_type: ContractType, contract_metadata: Dict[str, Any]
     ) -> str:
@@ -112,9 +120,3 @@ class ContractDeployer(ProviderHandler):
         )
 
         return self.__factory
-
-    def _set_registry(self, registry: ContractRegistry):
-        self.__registry = registry
-
-    def _set_factory(self, factory: ContractFactory):
-        self.__factory = factory
