@@ -1,8 +1,6 @@
-from dataclasses import dataclass
 import dataclasses
+from dataclasses import dataclass
 from typing import Any, BinaryIO, Dict, List, Optional, TextIO, Union
-
-from brownie import Contract
 from thirdweb.constants.currency import ZERO_ADDRESS
 from dacite import from_dict
 
@@ -21,7 +19,7 @@ class ContractMetadataSchema:
     def to_json(self) -> Dict[str, Any]:
         json = {}
         for key, value in self.__dict__.items():
-            if (value is not None and value is not "") or key == "name":
+            if (value is not None and value != "") or key == "name":
                 json[key] = value
         return json
 
